@@ -26,6 +26,7 @@
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
+#include <QRegularExpression>
 #include <QSharedData>
 
 #include <kconfiggroup.h>
@@ -200,18 +201,20 @@ class RunnerContextPrivate : public QSharedData
                 QUrl url = QUrl::fromUserInput(term);
                 // QUrl::fromUserInput assigns http to everything if it cannot match it to
                 // anything else. We do not want that.
-                if (url.scheme() == QStringLiteral("http")) {
-                    if (!term.startsWith(QStringLiteral("http"))) {
+                if (url.scheme() == QLatin1String("http")) {
+                    if (!term.startsWith(QLatin1String("http"))) {
                         url.setScheme(QString());
                     }
                 }
                 const bool hasProtocol = !url.scheme().isEmpty();
                 const bool isLocalProtocol = hasProtocol && KProtocolInfo::protocolClass(url.scheme()) == QLatin1String(":local");
-                if (hasProtocol &&
+                if ((hasProtocol &&
                     ((!isLocalProtocol && !url.host().isEmpty()) ||
-                     (isLocalProtocol && url.scheme() != QLatin1String("file")))) {
+                     (isLocalProtocol && url.scheme() != QLatin1String("file"))))
+                        || term.startsWith(QLatin1String("\\\\"))) {
                     // we either have a network protocol with a host, so we can show matches for it
                     // or we have a non-file url that may be local so a host isn't required
+                    // or we have an UNC path (\\foo\bar)
                     type = RunnerContext::NetworkLocation;
                 } else if (isLocalProtocol) {
                     // at this point in the game, we assume we have a path,
@@ -395,7 +398,7 @@ bool RunnerContext::addMatches(const QList<QueryMatch> &matches)
     }
 
     LOCK_FOR_WRITE(d)
-    foreach (QueryMatch match, matches) {
+    for (QueryMatch match : matches) {
         // Give previously launched matches a slight boost in relevance
         // The boost smoothly saturates to 0.5;
         if (int count = d->launchCounts.value(match.id())) {
@@ -454,7 +457,7 @@ bool RunnerContext::removeMatches(const QStringList matchIdList)
     QList<const QueryMatch*> presentMatchList;
 
     LOCK_FOR_READ(d)
-    foreach(const QString &matchId, matchIdList) {
+    for (const QString &matchId : matchIdList) {
         const QueryMatch* match = d->matchesById.value(matchId, nullptr);
         if (match) {
             presentMatchList << match;
@@ -468,10 +471,10 @@ bool RunnerContext::removeMatches(const QStringList matchIdList)
     }
 
     LOCK_FOR_WRITE(d)
-    foreach(const QueryMatch *match, presentMatchList) {
+    for (const QueryMatch *match : qAsConst(presentMatchList)) {
         d->matches.removeAll(*match);
     }
-    foreach(const QString &matchId, presentMatchIdList) {
+    for (const QString &matchId : qAsConst(presentMatchIdList)) {
         d->matchesById.remove(matchId);
     }
     UNLOCK(d)
@@ -510,7 +513,7 @@ bool RunnerContext::removeMatches(Plasma::AbstractRunner *runner)
     QList<QueryMatch> presentMatchList;
 
     LOCK_FOR_READ(d)
-    foreach(const QueryMatch &match, d->matches) {
+    for(const QueryMatch &match : qAsConst(d->matches)) {
         if (match.runner() == runner) {
             presentMatchList << match;
         }
@@ -522,7 +525,7 @@ bool RunnerContext::removeMatches(Plasma::AbstractRunner *runner)
     }
 
     LOCK_FOR_WRITE(d)
-    foreach (const QueryMatch &match, presentMatchList) {
+    for (const QueryMatch &match : qAsConst(presentMatchList)) {
         d->matchesById.remove(match.id());
         d->matches.removeAll(match);
     }
@@ -567,11 +570,14 @@ void RunnerContext::restore(const KConfigGroup &config)
 {
     const QStringList cfgList = config.readEntry("LaunchCounts", QStringList());
 
-    const QRegExp r(QStringLiteral("(\\d*) (.*)"));
-    foreach (const QString& entry, cfgList) {
-        r.indexIn(entry);
-        int count = r.cap(1).toInt();
-        QString id = r.cap(2);
+    const QRegularExpression re(QStringLiteral("(\\d*) (.+)"));
+    for (const QString& entry : cfgList) {
+        const QRegularExpressionMatch match = re.match(entry);
+        if (!match.hasMatch()) {
+            continue;
+        }
+        const int count = match.captured(1).toInt();
+        const QString id = match.captured(2);
         d->launchCounts[id] = count;
     }
 }
