@@ -21,7 +21,7 @@
 
 #include "runnermanager.h"
 
-#include <QMutex>
+#include <QElapsedTimer>
 #include <QTimer>
 #include <QCoreApplication>
 #include <qstandardpaths.h>
@@ -74,6 +74,10 @@ public:
         QObject::connect(&matchChangeTimer, SIGNAL(timeout()), q, SLOT(matchesChanged()));
         QObject::connect(&context, SIGNAL(matchesChanged()), q, SLOT(scheduleMatchesChanged()));
         QObject::connect(&delayTimer, SIGNAL(timeout()), q, SLOT(unblockJobs()));
+
+        // Set up tracking of the last time matchesChanged was signalled
+        lastMatchChangeSignalled.start();
+        QObject::connect(q, &RunnerManager::matchesChanged, q, [&] { lastMatchChangeSignalled.restart(); });
     }
 
     ~RunnerManagerPrivate()
@@ -84,7 +88,12 @@ public:
 
     void scheduleMatchesChanged()
     {
-        matchChangeTimer.start(100);
+        if(lastMatchChangeSignalled.hasExpired(250)) {
+            matchChangeTimer.stop();
+            emit q->matchesChanged(context.matches());
+        } else {
+            matchChangeTimer.start(250 - lastMatchChangeSignalled.elapsed());
+        }
     }
 
     void matchesChanged()
@@ -241,7 +250,7 @@ public:
                 while (it != searchJobs.end()) {
                     auto &job = (*it);
                     if (deadRunners.contains(job->runner())) {
-                        QObject::disconnect(job->decorator(), SIGNAL(done(ThreadWeaver::JobPointer)), q, SLOT(jobDone(ThreadWeaver::JobPointer)));
+                        QObject::disconnect(job.data(), SIGNAL(done(ThreadWeaver::JobPointer)), q, SLOT(jobDone(ThreadWeaver::JobPointer)));
                         it = searchJobs.erase(it);
                         deadJobs.insert(job);
                     } else {
@@ -345,6 +354,7 @@ public:
             emit q->matchesChanged(context.matches());
         }
 
+        teardownRequested = true;
         checkTearDown();
     }
 
@@ -363,7 +373,7 @@ public:
 
         if (searchJobs.isEmpty() && oldSearchJobs.isEmpty()) {
             if (allRunnersPrepped) {
-                foreach (AbstractRunner *runner, runners) {
+                for (AbstractRunner *runner : qAsConst(runners)) {
                     emit runner->teardown();
                 }
 
@@ -413,7 +423,7 @@ public:
     {
         if ((runner->ignoredTypes() & context.type()) == 0) {
             QSharedPointer<FindMatchesJob> job(new FindMatchesJob(runner, &context, Queue::instance()));
-            QObject::connect(job->decorator(), SIGNAL(done(ThreadWeaver::JobPointer)), q, SLOT(jobDone(ThreadWeaver::JobPointer)));
+            QObject::connect(job.data(), SIGNAL(done(ThreadWeaver::JobPointer)), q, SLOT(jobDone(ThreadWeaver::JobPointer)));
             if (runner->speed() == AbstractRunner::SlowSpeed) {
                 job->setDelayTimer(&delayTimer);
             }
@@ -430,6 +440,7 @@ public:
     RunnerContext context;
     QTimer matchChangeTimer;
     QTimer delayTimer; // Timer to control when to run slow runners
+    QElapsedTimer lastMatchChangeSignalled;
     QHash<QString, AbstractRunner*> runners;
     QHash<QString, QString> advertiseSingleRunnerIds;
     AbstractRunner* currentSingleRunner;
@@ -695,7 +706,7 @@ KPluginInfo::List RunnerManager::listRunnerInfo(const QString &parentApp)
     if (parentApp.isEmpty()) {
         constraint.append(QStringLiteral("not exist [X-KDE-ParentApp]"));
     } else {
-        constraint.append(QStringLiteral("[X-KDE-ParentApp] == '")).append(parentApp).append(QStringLiteral("'"));
+        constraint.append(QStringLiteral("[X-KDE-ParentApp] == '")).append(parentApp).append(QLatin1Char('\''));
     }
 
     KService::List offers = KServiceTypeTrader::self()->query(QStringLiteral("Plasma/Runner"), constraint);
@@ -717,7 +728,7 @@ void RunnerManager::setupMatchSession()
             d->singleRunnerPrepped = true;
         }
     } else {
-        foreach (AbstractRunner *runner, d->runners) {
+        for (AbstractRunner *runner : qAsConst(d->runners)) {
 #ifdef MEASURE_PREPTIME
             QTime t;
             t.start();
@@ -763,7 +774,7 @@ void RunnerManager::launchQuery(const QString &untrimmedTerm, const QString &run
 
     if (term.isEmpty()) {
         if (d->singleMode && d->currentSingleRunner->defaultSyntax()) {
-            term = d->currentSingleRunner->defaultSyntax()->exampleQueries().first().remove(QRegExp(QStringLiteral(":q:")));
+            term = d->currentSingleRunner->defaultSyntax()->exampleQueries().first().remove(QLatin1String(":q:"));
         } else {
             reset();
             return;
@@ -794,7 +805,7 @@ void RunnerManager::launchQuery(const QString &untrimmedTerm, const QString &run
         runable = d->runners;
     }
 
-    foreach (Plasma::AbstractRunner *r, runable) {
+    for (Plasma::AbstractRunner *r : qAsConst(runable)) {
         if (r->isMatchingSuspended()) {
             continue;
         }
@@ -833,6 +844,7 @@ void RunnerManager::reset()
     }
 
     d->context.reset();
+    emit queryFinished();
 }
 
 } // Plasma namespace
