@@ -22,8 +22,8 @@
 #ifndef PLASMA_RUNNERMANAGER_H
 #define PLASMA_RUNNERMANAGER_H
 
-#include <QtCore/QList>
-#include <QtCore/QObject>
+#include <QList>
+#include <QObject>
 
 #include <kplugininfo.h>
 
@@ -249,7 +249,7 @@ class KRUNNER_EXPORT RunnerManager : public QObject
         void matchSessionComplete();
 
         /**
-         * Launch a query, this will create threads and return inmediately.
+         * Launch a query, this will create threads and return immediately.
          * When the information will be available can be known using the
          * matchesChanged signal.
          *
